@@ -1,6 +1,6 @@
 __copyright__ = 'Copyright (C) 2019'
 __license__ = 'MIT'
-__version__ = "0.3.2"
+__version__ = "0.3.3"
 
 
 def setup(app):
@@ -16,3 +16,9 @@ def setup(app):
 
     app.add_node(Asciinema, **_NODE_VISITORS)
     app.add_directive('asciinema', ASCIINemaDirective)
+
+    return {
+        'version': __version__,
+        'parallel_read_safe': True,
+        'parallel_write_safe': True,
+    }
